@@ -165,10 +165,20 @@ def connect(pmacoreURL = _pma_pmacoreliteURL, pmacoreUsername = "", pmacorePassw
 	"""
 	Attempt to connect to PMA.core instance; success results in a SessionID
 	"""
+	global _pma_sessions						# so afterwards we can look up what username actually belongs to a sessions	
+	global _pma_usernames						# so afterwards we can determine the PMA.core URL to connect to for a given SessionID
+	global _pma_slideinfos						# a caching mechanism for slide information; obsolete and should be improved through pma._pma_http_get()
+	global _pma_amount_of_data_downloaded		# keep track of how much data was downloaded
+
 	if (pmacoreURL == _pma_pmacoreliteURL):
 		if is_lite():
 			# no point authenticating localhost / PMA.core.lite
-			return _pma_pmacoreliteSessionID
+			sessionID = _pma_pmacoreliteSessionID
+			_pma_sessions[sessionID] = pmacoreURL			
+			if not (sessionID in _pma_slideinfos):
+				_pma_slideinfos[sessionID] = {}
+			_pma_amount_of_data_downloaded[sessionID] = 0
+			return sessionID
 		else:
 			return None
 			
@@ -195,12 +205,7 @@ def connect(pmacoreURL = _pma_pmacoreliteURL, pmacoreUsername = "", pmacorePassw
 		sessionID = loginresult["SessionId"]
 		if (pma._pma_debug == True):
 			print("sessionID =", sessionID)
-			
-		global _pma_sessions						# so afterwards we can look up what username actually belongs to a sessions	
-		global _pma_usernames						# so afterwards we can determine the PMA.core URL to connect to for a given SessionID
-		global _pma_slideinfos						# a caching mechanism for slide information; obsolete and should be improved through pma._pma_http_get()
-		global _pma_amount_of_data_downloaded		# keep track of how much data was downloaded
-		
+
 		_pma_usernames[sessionID] = pmacoreUsername		
 		_pma_sessions[sessionID] = pmacoreURL			
 		if not (sessionID in _pma_slideinfos):
